utils::globalVariables(c("db_int",
                         "db_user",
                         "db_password",
                         "db_name",
                         "db_host",
                          "db_int",
                          "db_user",
                          "db_password",
                          "db_name",
                          "db_host",
                          "species",
                          "genus",
                          "runPlatform",
                          "geneSymbol",
                          "projectName",
                          "assayName",
                          "country",
                          "continent",
                          "stateProvince",
                          "locality",
                         "establishmentMeans",
                          "CqIntensity",
                         "CqIntensitySystemCalculated",
                         "write.csv",
                         "coef",
                          "standardConc",
                         "userProvidedCqValue",
                          "Residual",
                          "LOD",
                          "LOQ",
                          "cycles",
                         "th.cyc",
                         "Fluorescence",
                         "calculate_threshold_value",
                         "process_MIC_uploaded_file",
                         "process_SOP_uploaded_file",
                         "process_biomeme23_uploaded_file",
                         "reformat_SOP_Flur_data",
                         "add_CqValue",
                         "Cycle_Number1"))
